quantizationtools.BeatwiseQTarget
=================================

.. abjad-lineage:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget

.. autoclass:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.beats
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.duration_in_ms
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.item_class
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.items
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__call__
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__eq__
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__format__
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__ne__
      ~abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__repr__

Bases
-----

- :py:class:`quantizationtools.QTarget <abjad.tools.quantizationtools.QTarget.QTarget>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.beats
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.duration_in_ms
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.item_class
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.items
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__format__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.BeatwiseQTarget.BeatwiseQTarget.__repr__
   :noindex:
